@@ -30,8 +30,8 @@ from c8.exceptions import (
     StreamCommunicationError,
     StreamConnectionError,
     StreamCreateError,
+    StreamDeleteError,
     StreamPermissionError,
-    TransactionExecuteError,
     TenantDcListError,
     SpotRegionUpdateError,
     RestqlValidationError,
@@ -50,7 +50,6 @@ from c8.executor import (
     DefaultExecutor,
     AsyncExecutor,
     BatchExecutor,
-    TransactionExecutor,
 )
 from c8.graph import Graph
 from c8.stream_collection import StreamCollection
@@ -60,12 +59,13 @@ __all__ = [
     'StandardFabric',
     'AsyncFabric',
     'BatchFabric',
-    'TransactionFabric'
 ]
 ENDPOINT = "/streams"
 
+
 def raise_timeout(signum, frame):
-        raise TimeoutError
+    raise TimeoutError
+
 
 def printdata(event):
     """Prints the event.
@@ -102,7 +102,7 @@ class Fabric(APIWrapper):
 
         :param name: Collection name.
         :type name: str | unicode
-        :return: Collection API wrapper.
+        :returns: Collection API wrapper.
         :rtype: c8.collection.StandardCollection
         """
         return self.collection(name)
@@ -111,7 +111,7 @@ class Fabric(APIWrapper):
     def name(self):
         """Return fabric name.
 
-        :return: Fabric name.
+        :returns: Fabric name.
         :rtype: str | unicode
         """
         return self.fabric_name
@@ -120,7 +120,7 @@ class Fabric(APIWrapper):
     def c8ql(self):
         """Return C8QL (C8Db Query Language) API wrapper.
 
-        :return: C8QL API wrapper.
+        :returns: C8QL API wrapper.
         :rtype: c8.c8ql.C8QL
         """
         return C8QL(self._conn, self._executor)
@@ -129,12 +129,11 @@ class Fabric(APIWrapper):
     def key_value(self):
         """Return KV (Key Value) API wrapper.
 
-        :return: KV API wrapper.
+        :returns: KV API wrapper.
         :rtype: c8.keyvalue.KV
         """
         return KV(self._conn, self._executor)
 
-
     def on_change(self, collection, callback, timeout=60):
         """Execute given input function on receiving a change.
 
@@ -147,7 +146,7 @@ class Fabric(APIWrapper):
         """
         if not callback:
             raise ValueError('You must specify a callback function')
-        
+
         if not collection:
             raise ValueError('You must specify a collection on which realtime '
                              'data is to be watched!')
@@ -156,22 +155,23 @@ class Fabric(APIWrapper):
 
         subscription_name = "%s-%s-subscription-%s" % (
             self.tenant_name, self.fabric_name, str(random.randint(1, 1000)))
-        
+
         url = self.url.split("//")[1].split(":")[0]
 
         topic = "wss://{}/_ws/ws/v2/consumer/persistent/{}/{}/{}/{}".format(
-            url,self.tenant_name,namespace,
-            collection,subscription_name)
+            url, self.tenant_name, namespace,
+            collection, subscription_name)
+
+        ws = websocket.create_connection(
+            topic, header=self.header, timeout=timeout)
 
-        ws = websocket.create_connection(topic, header=self.header, timeout=timeout)
-        
         try:
             print("pyC8 Realtime: Begin monitoring realtime updates for " +
                   topic)
             while True:
                 msg = json.loads(ws.recv())
-                data =  base64.b64decode(msg['payload'])
-                ws.send(json.dumps({'messageId' : msg['messageId']}))
+                data = base64.b64decode(msg['payload'])
+                ws.send(json.dumps({'messageId': msg['messageId']}))
                 callback(data)
         except TimeoutError:
             pass
@@ -183,7 +183,7 @@ class Fabric(APIWrapper):
     def properties(self):
         """Return fabric properties.
 
-        :return: Fabric properties.
+        :returns: Fabric properties.
         :rtype: dict
         :raise c8.exceptions.FabricPropertiesError: If retrieval fails.
         """
@@ -201,106 +201,23 @@ class Fabric(APIWrapper):
 
         return self._execute(request, response_handler)
 
-    def execute_transaction(self,
-                            command,
-                            params=None,
-                            read=None,
-                            write=None,
-                            sync=None,
-                            timeout=None,
-                            max_size=None,
-                            allow_implicit=None,
-                            intermediate_commit_count=None,
-                            intermediate_commit_size=None):
-        """Execute raw Javascript command in transaction.
-
-        :param command: Javascript command to execute.
-        :type command: str | unicode
-        :param read: Names of collections read during transaction. If parameter
-            **allow_implicit** is set to True, any undeclared read collections
-            are loaded lazily.
-        :type read: [str | unicode]
-        :param write: Names of collections written to during transaction.
-            Transaction fails on undeclared write collections.
-        :type write: [str | unicode]
-        :param params: Optional parameters passed into the Javascript command.
-        :type params: dict
-        :param sync: Block until operation is synchronized to disk.
-        :type sync: bool
-        :param timeout: Timeout for waiting on collection locks. If set to 0,
-            C8Db server waits indefinitely. If not set, system default
-            value is used.
-        :type timeout: int
-        :param max_size: Max transaction size limit in bytes. Applies only
-            to RocksDB storage engine.
-        :type max_size: int
-        :param allow_implicit: If set to True, undeclared read collections are
-            loaded lazily. If set to False, transaction fails on any undeclared
-            collections.
-        :type allow_implicit: bool
-        :param intermediate_commit_count: Max number of operations after which
-            an intermediate commit is performed automatically. Applies only to
-            RocksDB storage engine.
-        :type intermediate_commit_count: int
-        :param intermediate_commit_size: Max size of operations in bytes after
-            which an intermediate commit is performed automatically. Applies
-            only to RocksDB storage engine.
-        :type intermediate_commit_size: int
-        :return: Return value of **command**.
-        :rtype: str | unicode
-        :raise c8.exceptions.TransactionExecuteError: If execution fails.
-        """
-        collections = {'allowImplicit': allow_implicit}
-        if read is not None:
-            collections['read'] = read
-        if write is not None:
-            collections['write'] = write
-
-        data = {'action': command}
-        if collections:
-            data['collections'] = collections
-        if params is not None:
-            data['params'] = params
-        if timeout is not None:
-            data['lockTimeout'] = timeout
-        if sync is not None:
-            data['waitForSync'] = sync
-        if max_size is not None:
-            data['maxTransactionSize'] = max_size
-        if intermediate_commit_count is not None:
-            data['intermediateCommitCount'] = intermediate_commit_count
-        if intermediate_commit_size is not None:
-            data['intermediateCommitSize'] = intermediate_commit_size
-
-        request = Request(
-            method='post',
-            endpoint='/transaction',
-            data=data
-        )
-
-        def response_handler(resp):
-            if not resp.is_success:
-                raise TransactionExecuteError(resp, request)
-            return resp.body.get('result')
-
-        return self._execute(request, response_handler)
-
     def update_spot_region(self, tenant, fabric, new_dc):
         """Updates spot primary region for the geo-fabric
-            :param: tenant: tenant name
-            :type: str
-            :param: fabric: fabric name
-            :type: str
-            :param: new_dc: New spot region
-            :type: str
-            :return: True if request successful,false otherwise
-            :rtype: bool
-            :raise c8.exceptions.SpotRegionUpdateError: If updation fails.
+
+        :param tenant: tenant name
+        :type tenant: str
+        :param fabric: fabric name
+        :type fabric: str
+        :param new_dc: New spot region
+        :type new_dc: str
+        :returns: True if request successful,false otherwise
+        :rtype: bool
+        :raise c8.exceptions.SpotRegionUpdateError: If updation fails.
         """
 
         request = Request(method='put',
                           endpoint='_fabric/{}/database/{}'.format(
-                          fabric, new_dc))
+                              fabric, new_dc))
 
         def response_handler(resp):
             if not resp.is_success:
@@ -328,7 +245,7 @@ class Fabric(APIWrapper):
     def version(self):
         """Return C8Db server version.
 
-        :return: Server version.
+        :returns: Server version.
         :rtype: str | unicode
         :raise c8.exceptions.ServerVersionError: If retrieval fails.
         """
@@ -348,7 +265,7 @@ class Fabric(APIWrapper):
     def ping(self):
         """Ping the C8Db server by sending a test request.
 
-        :return: Response code from server.
+        :returns: Response code from server.
         :rtype: int
         :raise c8.exceptions.ServerConnectionError: If ping fails.
         """
@@ -377,7 +294,7 @@ class Fabric(APIWrapper):
 
         :param detail: detail list of DCs if set to true else only DC names
         :type: boolean
-        :return: DC List.
+        :returns: DC List.
         :rtype: [str | unicode ]
         :raise c8.exceptions.TenantListError: If retrieval fails.
         """
@@ -408,7 +325,7 @@ class Fabric(APIWrapper):
 
         :param detail: detail list of DCs if set to true else only DC names
         :type: boolean
-        :return: DC List.
+        :returns: DC List.
         :rtype: [str | dict ]
         :raise c8.exceptions.TenantListError: If retrieval fails.
         """
@@ -433,7 +350,7 @@ class Fabric(APIWrapper):
     def fabrics(self):
         """Return the names all fabrics.
 
-        :return: Fabric names.
+        :returns: Fabric names.
         :rtype: [str | unicode]
         :raise c8.exceptions.FabricListError: If retrieval fails.
         """
@@ -454,7 +371,7 @@ class Fabric(APIWrapper):
 
         :param name: Fabric name.
         :type name: str | unicode
-        :return: True if fabric exists, False otherwise.
+        :returns: True if fabric exists, False otherwise.
         :rtype: bool
         """
         return name in self.fabrics()
@@ -481,9 +398,9 @@ class Fabric(APIWrapper):
             and "extra" (see below for example). If not set, only the admin and
             current user are granted access.
         :type users: [dict]
-        :param dclist : list of strings of datacenters
+        :param dclist: list of strings of datacenters
         :type dclist: [str | unicode]
-        :return: True if fabric was created successfully.
+        :returns: True if fabric was created successfully.
         :rtype: bool
         :raise c8.exceptions.FabricCreateError: If create fails.
 
@@ -497,6 +414,7 @@ class Fabric(APIWrapper):
                 'active': True,
                 'extra': {'Department': 'IT'}
             }
+
         """
         data = {'name': name}
         if users is not None:
@@ -546,7 +464,7 @@ class Fabric(APIWrapper):
         :type name: str | unicode
         :param ignore_missing: Do not raise an exception on missing fabric.
         :type ignore_missing: bool
-        :return: True if fabric was deleted successfully, False if fabric
+        :returns: True if fabric was deleted successfully, False if fabric
             was not found and **ignore_missing** was set to True.
         :rtype: bool
         :raise c8.exceptions.FabricDeleteError: If delete fails.
@@ -574,7 +492,7 @@ class Fabric(APIWrapper):
 
         :param name: Collection name.
         :type name: str | unicode
-        :return: Standard collection API wrapper.
+        :returns: Standard collection API wrapper.
         :rtype: c8.collection.StandardCollection
         """
         if self.has_collection(name):
@@ -587,7 +505,7 @@ class Fabric(APIWrapper):
 
         :param name: Collection name.
         :type name: str | unicode
-        :return: True if collection exists, False otherwise.
+        :returns: True if collection exists, False otherwise.
         :rtype: bool
         """
         return any(col['name'] == name for col in self.collections())
@@ -595,7 +513,7 @@ class Fabric(APIWrapper):
     def collections(self, collectionModel=None):
         """Return the collections in the fabric.
 
-        :return: Collections in the fabric and their details.
+        :returns: Collections in the fabric and their details.
         :rtype: [dict]
         :raise c8.exceptions.CollectionListError: If retrieval fails.
         """
@@ -608,7 +526,8 @@ class Fabric(APIWrapper):
             if not resp.is_success:
                 raise CollectionListError(resp, request)
             if collectionModel is not None:
-                docs =  [col for col in map(dict, resp.body['result']) if col['collectionModel'] == collectionModel]
+                docs = [col for col in map(
+                    dict, resp.body['result']) if col['collectionModel'] == collectionModel]
             else:
                 docs = [col for col in map(dict, resp.body['result'])]
             return [{
@@ -637,7 +556,8 @@ class Fabric(APIWrapper):
                           enforce_replication_factor=None,
                           spot_collection=False,
                           local_collection=False,
-                          is_system=False
+                          is_system=False,
+                          stream=False
                           ):
         """Create a new collection.
 
@@ -680,10 +600,12 @@ class Fabric(APIWrapper):
             available at creation time, or halt the operation.
         :type enforce_replication_factor: bool
         :param spot_collection: If True, it is a spot collection
-        :type bool
+        :type spot_collection: bool
         :param is_system: If True, able to create system collections
         :type is_system: bool
-        :return: Standard collection API wrapper.
+        :param stream: If True, create a local stream for collection.
+        :type stream: bool
+        :returns: Standard collection API wrapper.
         :rtype: c8.collection.StandardCollection
         :raise c8.exceptions.CollectionCreateError: If create fails.
         """
@@ -702,7 +624,8 @@ class Fabric(APIWrapper):
                 'type': 3 if edge else 2,
                 'isSpot': spot_collection,
                 'isLocal': local_collection,
-                'isSystem': is_system
+                'isSystem': is_system,
+                'stream': stream,
             }
 
         if shard_fields is not None:
@@ -739,7 +662,7 @@ class Fabric(APIWrapper):
         :type ignore_missing: bool
         :param system: Whether the collection is a system collection.
         :type system: bool
-        :return: True if collection was deleted successfully, False if
+        :returns: True if collection was deleted successfully, False if
             collection was not found and **ignore_missing** was set to True.
         :rtype: bool
         :raise c8.exceptions.CollectionDeleteError: If delete fails.
@@ -772,7 +695,7 @@ class Fabric(APIWrapper):
 
         :param name: Graph name.
         :type name: str | unicode
-        :return: Graph API wrapper.
+        :returns: Graph API wrapper.
         :rtype: c8.graph.Graph
         """
         return Graph(self._conn, self._executor, name)
@@ -782,7 +705,7 @@ class Fabric(APIWrapper):
 
         :param name: Graph name.
         :type name: str | unicode
-        :return: True if graph exists, False otherwise.
+        :returns: True if graph exists, False otherwise.
         :rtype: bool
         """
         for graph in self.graphs():
@@ -793,7 +716,7 @@ class Fabric(APIWrapper):
     def graphs(self):
         """List all graphs in the fabric.
 
-        :return: Graphs in the fabric.
+        :returns: Graphs in the fabric.
         :rtype: [dict]
         :raise c8.exceptions.GraphListError: If retrieval fails.
         """
@@ -845,7 +768,7 @@ class Fabric(APIWrapper):
             cannot be modified later once set. Applies only to enterprise
             version of C8Db.
         :type shard_count: int
-        :return: Graph API wrapper.
+        :returns: Graph API wrapper.
         :rtype: c8.graph.Graph
         :raise c8.exceptions.GraphCreateError: If create fails.
 
@@ -894,7 +817,7 @@ class Fabric(APIWrapper):
         :param drop_collections: Drop the collections of the graph also. This
             is only if they are not in use by other graphs.
         :type drop_collections: bool
-        :return: True if graph was deleted successfully, False if graph was not
+        :returns: True if graph was deleted successfully, False if graph was not
             found and **ignore_missing** was set to True.
         :rtype: bool
         :raise c8.exceptions.GraphDeleteError: If delete fails.
@@ -930,7 +853,7 @@ class Fabric(APIWrapper):
     #     :type status: str | unicode
     #     :param count: Max number of job IDs to return.
     #     :type count: int
-    #     :return: List of job IDs.
+    #     :returns: List of job IDs.
     #     :rtype: [str | unicode]
     #     :raise c8.exceptions.AsyncJobListError: If retrieval fails.
     #     """
@@ -960,7 +883,7 @@ class Fabric(APIWrapper):
     #         the threshold (a unix timestamp) are deleted. Otherwise, all job
     #         results are deleted.
     #     :type threshold: int
-    #     :return: True if job results were cleared successfully.
+    #     :returns: True if job results were cleared successfully.
     #     :rtype: bool
     #     :raise c8.exceptions.AsyncJobClearError: If operation fails.
     #     """
@@ -991,7 +914,7 @@ class Fabric(APIWrapper):
     def stream(self, operation_timeout_seconds=30):
         """Return the stream collection API wrapper.
 
-        :return: stream collection API wrapper.
+        :returns: stream collection API wrapper.
         :rtype: c8.stream_collection.StreamCollection
         """
         return StreamCollection(self, self._conn, self._executor, self.url,
@@ -1000,7 +923,7 @@ class Fabric(APIWrapper):
     def streams(self, local=False):
         """Get list of all streams under given fabric
 
-        :return: List of streams under given fabric.
+        :returns: List of streams under given fabric.
         :rtype: json
         :raise c8.exceptions.StreamListError: If retrieving streams fails.
         """
@@ -1033,31 +956,29 @@ class Fabric(APIWrapper):
 
         return self._execute(request, response_handler)
 
- 
     def has_stream(self, stream, isCollectionStream=False, local=False):
-     
         """ Check if the list of streams has a stream with the given name.
 
         :param stream: The name of the stream for which to check in the list
                        of all streams.
         :type stream: str | unicode
-        :return: True=stream found; False=stream not found.
+        :returns: True=stream found; False=stream not found.
         :rtype: bool
         """
         if isCollectionStream is False:
             if local is False and "c8globals" not in stream:
                 stream = "c8globals." + stream
             elif local is True and "c8locals" not in stream:
-                stream = "c8locals." + stream     
+                stream = "c8locals." + stream
         return any(mystream['name'] == stream for mystream in self.streams(local=local))
 
-
     def create_stream(self, stream, local=False):
         """
         Create the stream under the given fabric
+
         :param stream: name of stream
         :param local: Operate on a local stream instead of a global one.
-        :return: 200, OK if operation successful
+        :returns: 200, OK if operation successful
         :raise: c8.exceptions.StreamDeleteError: If creating streams fails.
         """
         if local is True:
@@ -1077,47 +998,32 @@ class Fabric(APIWrapper):
 
         return self._execute(request, response_handler)
 
-    def delete_stream(self, stream, force=False, isCollectionStream=False, local=False):
+    def delete_stream(self, stream, force=False):
         """
         Delete the streams under the given fabric
+
         :param stream: name of stream
         :param force:
-        :param local: Operate on a local stream instead of a global one.
-        :return: 200, OK if operation successful
+        :returns: 200, OK if operation successful
         :raise: c8.exceptions.StreamDeleteError: If deleting streams fails.
         """
-        # KARTIK : 20181002 : Stream delete not supported.
-        # We still have some issues to work through for stream deletion on the
-        # pulsar side. So for v0.9.0 we only support terminate, and that too
-        # only for persistent streams.
-        print("WARNING: Delete not yet implemented for persistent streams, "
-              "calling terminate instead.")
-        # if isCollectionStream is False:
-           # if local is True:
-              #  stream = "c8locals." + stream
-            #else:
-             #   stream = "c8globals." + stream
-        return self.terminate_stream(stream=stream, isCollectionStream=isCollectionStream,  local=local)
+        endpoint = f'{ENDPOINT}/{stream}'
+        if force:
+           endpoint = endpoint + "?force=true"
 
-        # TODO : When stream delete is implemented, enable below code and
-        # remove the above code.
-        # endpoint = '{}/{}?local={}'.format(ENDPOINT, stream, local)
-        # if force:
-        #    endpoint = endpoint + "&force=true"
-        #
-        # request = Request(method='delete', endpoint=endpoint)
-        #
-        # def response_handler(resp):
-        #    code = resp.status_code
-        #    if resp.is_success:
-        #        return resp.body['result']
-        #    elif code == 403:
-        #        raise StreamPermissionError(resp, request)
-        #    elif code == 412:
-        #        raise StreamDeleteError(resp, request)
-        #    raise StreamConnectionError(resp, request)
-        #
-        # return self._execute(request, response_handler)
+        request = Request(method='delete', endpoint=endpoint)
+
+        def response_handler(resp):
+           code = resp.status_code
+           if resp.is_success:
+               return resp.body['result']
+           elif code == 403:
+               raise StreamPermissionError(resp, request)
+           elif code == 412:
+               raise StreamDeleteError(resp, request)
+           raise StreamConnectionError(resp, request)
+
+        return self._execute(request, response_handler)
 
     def terminate_stream(self, stream, isCollectionStream=False, local=False):
         """Terminate a stream. A stream that is terminated will not accept any
@@ -1126,7 +1032,7 @@ class Fabric(APIWrapper):
 
         :param stream: name of stream
         :param local: Operate on a local stream instead of a global one.
-        :return: 200, OK if operation successful
+        :returns: 200, OK if operation successful
         :raise: c8.exceptions.StreamPermissionError: Dont have permission.
         """
         if isCollectionStream is False:
@@ -1156,7 +1062,7 @@ class Fabric(APIWrapper):
 
         :param data: data to be used for restql POST API
         :type data: dict
-        :return: Results of restql API
+        :returns: Results of restql API
         :rtype: dict
         :raise c8.exceptions.RestqlCreateError: if restql operation failed
         """
@@ -1182,7 +1088,7 @@ class Fabric(APIWrapper):
         :type name: str | unicode
         :param data: restql data (optional)
         :type data: dict
-        :return: Results of execute restql
+        :returns: Results of execute restql
         :rtype: dict
         :raise c8.exceptions.RestqlExecuteError: if restql execution failed
         """
@@ -1204,7 +1110,7 @@ class Fabric(APIWrapper):
     def get_all_restql(self):
         """Get all restql associated for user.
 
-        :return: Details of all restql
+        :returns: Details of all restql
         :rtype: list
         :raise c8.exceptions.RestqlListError: if getting restql failed
         """
@@ -1225,7 +1131,7 @@ class Fabric(APIWrapper):
         :type name: str | unicode
         :param data: restql data
         :type data: dict
-        :return: True if restql is updated
+        :returns: True if restql is updated
         :rtype: bool
         :raise c8.exceptions.RestqlUpdateError: if query update failed
         """
@@ -1243,7 +1149,7 @@ class Fabric(APIWrapper):
 
         :param name: restql name
         :type name: str | unicode
-        :return: True if restql is deleted
+        :returns: True if restql is deleted
         :rtype: bool
         :raise c8.exceptions.RestqlDeleteError: if restql deletion failed
         """
@@ -1265,13 +1171,14 @@ class Fabric(APIWrapper):
 
         :param payload: Payload to create event
         :type payload: dict
-        :return:  Dictionary containing the event id
+        :returns:  Dictionary containing the event id
         :rtype: dict
         :raise c8.exceptions.EventCreateError: if event creation failed
 
         Here is an example entry for parameter **payload**:
 
         .. code-block:: python
+
             {
             "action": "string",
             "attributes": {},
@@ -1296,14 +1203,14 @@ class Fabric(APIWrapper):
 
         :param eventIds: The event id for which you want to fetch the event details
         :type eventId: list of strings(event Ids)
-        :return: List containig all the information of existing events
+        :returns: List containig all the information of existing events
         :rtype: list
         :raise c8.exceptions.EventDeleteError: if event creation failed
 
         """
         data = (json.dumps((eventIds)))
 
-        request = Request(method="delete", endpoint="/events", data = data)
+        request = Request(method="delete", endpoint="/events", data=data)
 
         def response_handler(resp):
             if not resp.is_success:
@@ -1315,7 +1222,7 @@ class Fabric(APIWrapper):
     def get_all_events(self):
         """Create an event.
 
-        :return: List containig all the information of existing events
+        :returns: List containig all the information of existing events
         :rtype: list
         :raise c8.exceptions.EventGetError: if event creation failed
 
@@ -1328,12 +1235,12 @@ class Fabric(APIWrapper):
             return resp.body
 
         return self._execute(request, response_handler)
-    
+
     def get_event_by_Id(self, eventId):
         """Create an event.
 
         :param eventId: The event id for which you want to fetch the event details
-        :return: List containig all the information of existing events
+        :returns: List containig all the information of existing events
         :rtype: list
         :raise c8.exceptions.EventGetError: if event creation failed
 
@@ -1345,83 +1252,85 @@ class Fabric(APIWrapper):
                 raise EventGetError(resp, request)
             return resp.body
 
-        return self._execute(request, response_handler)     
+        return self._execute(request, response_handler)
 
     ########################
     # Stream Apps #
     ########################
 
-    def stream_app(self,name):
+    def stream_app(self, name):
         return StreamApps(self._conn, self._executor, name)
 
     def validate_stream_app(self, data):
         """validates a stream app by given data
-        @data: stream app defination string
+
+        :param data: stream app defination string
         """
         body = {"definition": data}
         req = Request(
-            method = "post",
+            method="post",
             endpoint='/streamapps/validate',
             data=json.dumps(body)
         )
-        
+
         def response_handler(resp):
             if resp.is_success is True:
                 return True
             print(resp.body)
             return False
-        
-        return self._execute(req,response_handler)
+
+        return self._execute(req, response_handler)
 
     def retrive_stream_app(self):
         """retrieves a stream app by given body
         """
         req = Request(
-            method = "get",
+            method="get",
             endpoint='/streamapps',
         )
-        
+
         def response_handler(resp):
             if resp.is_success is True:
                 return resp.body
             print(resp.body)
             return False
-        
-        return self._execute(req,response_handler)
+
+        return self._execute(req, response_handler)
 
     def get_samples_stream_app(self):
         """gets samples for stream apps
         """
         req = Request(
-            method = "get",
+            method="get",
             endpoint='/streamapps/samples',
         )
-        
+
         def response_handler(resp):
             if resp.is_success is not True:
-                raise StreamAppGetSampleError(resp,req)
-            return resp.body["streamAppSample"]    
-            
-        
-        return self._execute(req,response_handler)
+                raise StreamAppGetSampleError(resp, req)
+            return resp.body["streamAppSample"]
+
+        return self._execute(req, response_handler)
 
     def create_stream_app(self, data, dclist=[]):
         """Creates a stream application by given data
-        @data: stream app definition
-        @dclist: regions where stream app has to be deployed
+
+        :param data: stream app definition
+        :param dclist: regions where stream app has to be deployed
         """
         # create request body
         req_body = {
-            "definition":data,
-            "regions":dclist
-        } 
+            "definition": data,
+            "regions": dclist
+        }
         # create request
         req = Request(
-            method = "post",
+            method="post",
             endpoint='/streamapps',
             data=json.dumps(req_body)
         )
         # create response handler
+
         def response_handler(resp):
             if resp.is_success is True:
                 print(resp.body)
@@ -1429,33 +1338,34 @@ class Fabric(APIWrapper):
             print(resp.body)
             return False
         # call api
-        return self._execute(req,response_handler)   
-
+        return self._execute(req, response_handler)
 
     ########################
     # APIKeys #
     ########################
+
     def api_keys(self, keyid):
         """Return the API keys API wrapper.
+
         :param keyid: API Key id
         :type kaeyid: string | unicode
-        :return:API keys API wrapper.
+        :returns: API keys API wrapper.
         :rtype: c8.stream_collection.StreamCollection
         """
         return APIKeys(self._conn, self._executor, keyid)
 
-
     def list_all_api_keys(self):
         """List the API keys.
 
-        :return:list.
+        :returns:list.
         :raise c8.exceptions.GetAPIKeys: If request fails
         """
         request = Request(
-            method = "get",
+            method="get",
             endpoint='/key',
         )
         # create response handler
+
         def response_handler(resp):
             if not resp.is_success:
                 raise GetAPIKeys(resp, request)
@@ -1468,11 +1378,12 @@ class Fabric(APIWrapper):
     ##############################
     def search(self):
         """Returns the Search APIWrapper
-        :return: Search API Wrapper
+        :returns: Search API Wrapper
         :rtype: c8.search.Search
-        """ 
+        """
         return Search(self._conn, self._executor)
 
+
 class StandardFabric(Fabric):
     """Standard fabric API wrapper.
 
@@ -1497,7 +1408,7 @@ class StandardFabric(Fabric):
             results from server once available. If set to False, API executions
             return None and no results are stored on server.
         :type return_result: bool
-        :return: Fabric API wrapper built specifically for async execution.
+        :returns: Fabric API wrapper built specifically for async execution.
         :rtype: c8.fabric.AsyncFabric
         """
         return AsyncFabric(self._conn, return_result)
@@ -1510,48 +1421,11 @@ class StandardFabric(Fabric):
             commit. If set to False, API executions return None and no results
             are tracked client-side.
         :type return_result: bool
-        :return: Fabric API wrapper built specifically for batch execution.
+        :returns: Fabric API wrapper built specifically for batch execution.
         :rtype: c8.fabric.BatchFabric
         """
         return BatchFabric(self._conn, return_result)
 
-    def begin_transaction(self,
-                          return_result=True,
-                          timeout=None,
-                          sync=None,
-                          read=None,
-                          write=None):
-        """Begin transaction.
-
-        :param return_result: If set to True, API executions return instances
-            of :class:`c8.job.TransactionJob` that are populated with
-            results on commit. If set to False, API executions return None and
-            no results are tracked client-side.
-        :type return_result: bool
-        :param read: Names of collections read during transaction. If not
-            specified, they are added automatically as jobs are queued.
-        :type read: [str | unicode]
-        :param write: Names of collections written to during transaction.
-            If not specified, they are added automatically as jobs are queued.
-        :type write: [str | unicode]
-        :param timeout: Timeout for waiting on collection locks. If set to 0,
-            C8Db server waits indefinitely. If not set, system default
-            value is used.
-        :type timeout: int
-        :param sync: Block until the transaction is synchronized to disk.
-        :type sync: bool
-        :return: Fabric API wrapper built specifically for transactions.
-        :rtype: c8.fabric.TransactionFabric
-        """
-        return TransactionFabric(
-            connection=self._conn,
-            return_result=return_result,
-            read=read,
-            write=write,
-            timeout=timeout,
-            sync=sync
-        )
-
 
 class AsyncFabric(Fabric):
     """Fabric API wrapper tailored specifically for async execution.
@@ -1610,7 +1484,7 @@ class BatchFabric(Fabric):
     def queued_jobs(self):
         """Return the queued batch jobs.
 
-        :return: Queued batch jobs or None if **return_result** parameter was
+        :returns: Queued batch jobs or None if **return_result** parameter was
             set to False during initialization.
         :rtype: [c8.job.BatchJob] | None
         """
@@ -1622,7 +1496,7 @@ class BatchFabric(Fabric):
         If **return_result** parameter was set to True during initialization,
         :class:`c8.job.BatchJob` instances are populated with results.
 
-        :return: Batch jobs, or None if **return_result** parameter was set to
+        :returns: Batch jobs, or None if **return_result** parameter was set to
             False during initialization.
         :rtype: [c8.job.BatchJob] | None
         :raise c8.exceptions.BatchStateError: If batch state is invalid
@@ -1631,76 +1505,3 @@ class BatchFabric(Fabric):
         :raise c8.exceptions.BatchExecuteError: If commit fails.
         """
         return self._executor.commit()
-
-
-class TransactionFabric(Fabric):
-    """Fabric API wrapper tailored specifically for transactions.
-
-    See :func:`c8.fabric.StandardFabric.begin_transaction`.
-
-    :param connection: HTTP connection.
-    :type connection: c8.connection.Connection
-    :param return_result: If set to True, API executions return instances of
-        :class:`c8.job.TransactionJob` that are populated with results on
-        commit. If set to False, API executions return None and no results are
-        tracked client-side.
-    :type return_result: bool
-    :param read: Names of collections read during transaction.
-    :type read: [str | unicode]
-    :param write: Names of collections written to during transaction.
-    :type write: [str | unicode]
-    :param timeout: Timeout for waiting on collection locks. If set to 0, the
-        C8Db server waits indefinitely. If not set, system default value
-        is used.
-    :type timeout: int
-    :param sync: Block until operation is synchronized to disk.
-    :type sync: bool
-    """
-
-    def __init__(self, connection, return_result, read, write, timeout, sync):
-        super(TransactionFabric, self).__init__(
-            connection=connection,
-            executor=TransactionExecutor(
-                connection=connection,
-                return_result=return_result,
-                read=read,
-                write=write,
-                timeout=timeout,
-                sync=sync
-            )
-        )
-
-    def __repr__(self):
-        return '<TransactionFabric {}>'.format(self.name)
-
-    def __enter__(self):
-        return self
-
-    def __exit__(self, exception, *_):
-        if exception is None:
-            self._executor.commit()
-
-    def queued_jobs(self):
-        """Return the queued transaction jobs.
-
-        :return: Queued transaction jobs, or None if **return_result** was set
-            to False during initialization.
-        :rtype: [c8.job.TransactionJob] | None
-        """
-        return self._executor.jobs
-
-    def commit(self):
-        """Execute the queued requests in a single transaction API request.
-
-        If **return_result** parameter was set to True during initialization,
-        :class:`c8.job.TransactionJob` instances are populated with
-        results.
-
-        :return: Transaction jobs, or None if **return_result** parameter was
-            set to False during initialization.
-        :rtype: [c8.job.TransactionJob] | None
-        :raise c8.exceptions.TransactionStateError: If the transaction was
-            already committed.
-        :raise c8.exceptions.TransactionExecuteError: If commit fails.
-        """
-        return self._executor.commit()
